/*==============================================================================


       eg_21 - Keyboard Functions

               Copyright  2001 Pankhurst Algorithmics - All Rights Reserved
               visit www.ebmDevMag.com for permissions/restrictions on use

==============================================================================*/
#include <string.h>
#include <locale.h>
#include <stdlib.h>

#include "gui.h"
#include "ebm_object.h"

extern "C"
{
#include "ereader_hostio.h"
}
#include "eg_21_form.h"
/*==============================================================================

       main window

==============================================================================*/
void CWindow1::Initialize(void)
{
  CLabel *array[]={ Label1,  Label2,  Label3,  Label4,  Label5,  Label6,
                    Label7,  Label8,  Label9, Label10, Label11, Label12 };
  // simple way to intiaize an array with a group of identical objects
  for (int i=0;i<12;i++)
  {
    m_label[i]=array[i];  // assign objects to array
    m_text[i] =0; // clear pointers
    m_label[i]->SetLabel(""); // clear entries
  }
}
//------------------------------------------------------------------------------
CWindow1::~CWindow1(void)
{
  // free up memory for label strings
  for (int i=0;i<12;i++)
    delete[] m_text[i];
}
//------------------------------------------------------------------------------
S32 CWindow1::MsgHandler( MSG_TYPE type, CViewable *from, S32 data )
{
	if ( MSG_KEY==type )
  {
    char *ptr="", buff[80]="", text[80]="";
    switch (data)
    {
      case K_MENU:
        ptr="K_MENU";
        break;
      case K_KEYBOARD:
        ptr="K_KEYBOARD";
        break;
      case K_TOP:
        ptr="K_TOP";
        break;
      case K_LEFT:
        ptr="K_LEFT";
        break;
      case K_UP:
        ptr="K_UP";
        break;
      case K_JOG_UP:
        ptr="K_JOG_UP";
        break;
      case K_RIGHT:
        ptr="K_RIGHT";
        break;
      case K_DOWN:
        ptr="K_DOWN";
        break;
      case K_JOG_DOWN:
        ptr="K_JOG_DOWN";
        break;
      case K_PAGE_UP:
        ptr="K_PAGE_UP";
        break;
      case K_JOG_PAGE_UP:
        ptr="K_JOG_PAGE_UP";
        break;
      case K_PAGE_DOWN:
        ptr="K_PAGE_DOWN";
        break;
      case K_JOG_PAGE_DOWN:
        ptr="K_JOG_PAGE_DOWN";
        break;
      case K_BOTTOM:
        ptr="K_BOTTOM";
        break;
      case K_ENTER:
        ptr="K_ENTER";
        break;
      case K_JOG_ENTER:
        ptr="K_JOG_ENTER";
        break;
      case K_DELETE:
        ptr="K_DELETE";
        break;
      case K_BACKSPACE:
        ptr="K_BACKSPACE";
        break;
      default:
        sprintf(buff,"%c",(char)data);
        ptr=buff;
        break;
    }
    // move entries up in display list (just pointers)
    sprintf(text,"code 0x%04x='%s'",(int)data,ptr);
    delete[] m_text[0]; // remove top entry
    int i=0;
    for (i=1;i<12;i++) // now move text up...
      m_text[i-1]=m_text[i];
    // now add new string at bottom of array
    m_text[11]=new char[strlen(text)+1];
    strcpy(m_text[11],text);
    // now redraw all labels
    for (i=0;i<12;i++) // move text up...
    {
      if (m_text[i]) // non-NULL?
        m_label[i]->SetLabel(m_text[i]);
    }
    // one last detail - we want to display the keyboard, so handle commands
    // we allow a cheat - we can use the letter k to call it up as well
    // (only on the simulator, however)
    if ( K_KEYBOARD==data || ( hostIO_is_simulator() && 'k'==data ) )
    {
      static bool inUse=false;
      if ( ! inUse )
      {
        inUse=true;
        CLatin1Keyboard *keyboard=new CLatin1Keyboard(99,0); // 0->top of screen (default is 69)
        keyboard->SetCurScreen(0); // choose keyboard #0 - lowercase
        GUI_EventLoop(keyboard); // display keyboard
        inUse=false;
      }
    }
    return 1; // handled - prevents beeping
  }
  return CWindow::MsgHandler(type, from, data);
}
/*==============================================================================




==============================================================================*/
static CWindow1 *f_mainWindow;
//------------------------------------------------------------------------------
S32 GUI_main( MSG_TYPE type, CViewable *object, S32 data )
{
  switch (type)
  {
    case MSG_APP_START:
      if (OS_is_present && hostIO_am_I_the_current_task())
        HOSTIO_INLINE_BREAKPOINT();
      f_mainWindow = new CWindow1();
      f_mainWindow->Initialize(); // set up indexed array
      return 1;
    case MSG_APP_STOP:
      delete f_mainWindow;
      return 1;
    default:
      break;
  }
  return 0;
};
//------------------------------------------------------------------------------



